@@ -40,6 +40,26 @@ class AuthenticateView(View):
         return redirect(url)
 
 
+class AuthorizeView(View):
+    def get(self, *args, **kwargs):
+        uuid = kwargs['uuid']
+        provider = Provider.objects.get(uuid=uuid)
+
+        try:
+            token = provider.token_set.get()
+        except Token.DoesNotExist:
+            token = provider.token_set.create()
+
+        # TODO: redirect to the AuthenticateView instead of copying this logic
+        redirect_uri = self.request.build_absolute_uri(reverse('oauthclient:auth_code'))
+
+        # extract the UUID field from the Token model
+        provider_logic = OAuth2Client(provider, token=token)
+        url = provider_logic.get_authentication_url(redirect_uri)
+
+        return redirect(url)
+
+
 class ProviderView(View):
     def get(self, *args, **kwargs):
         provider_uuid = kwargs['uuid']
